@@ -1,4 +1,3 @@
-mod children;
 #[cfg(feature = "json")]
 mod json;
 #[cfg(feature = "parse")]
@@ -8,13 +7,13 @@ mod print;
 #[cfg(feature = "render")]
 mod render;
 
+use crate::mj_raw::MJRawChild;
 use crate::prelude::hash::Map;
-pub use children::MJNavbarLinkChild;
 
 pub const NAME: &str = "mj-navbar-link";
 
 #[derive(Debug, Default)]
 pub struct MJNavbarLink {
     attributes: Map<String, String>,
-    children: Vec<MJNavbarLinkChild>,
+    children: Vec<MJRawChild>,
 }
